@@ -93,4 +93,10 @@ class DescribeMonitorGroupsRequest(RpcRequest):
 		return self.get_query_params().get('InstanceId')
 
 	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+		self.add_query_param('InstanceId',InstanceId)
+
+	def get_ServiceId(self):
+		return self.get_query_params().get('ServiceId')
+
+	def set_ServiceId(self,ServiceId):
+		self.add_query_param('ServiceId',ServiceId)
\ No newline at end of file
