@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+
 class DescribeSiteMonitorStatisticsRequest(RpcRequest):
 
 	def __init__(self):
@@ -29,6 +30,12 @@ class DescribeSiteMonitorStatisticsRequest(RpcRequest):
 	def set_TimeRange(self,TimeRange):
 		self.add_query_param('TimeRange',TimeRange)
 
+	def get_StartTime(self):
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self,StartTime):
+		self.add_query_param('StartTime',StartTime)
+
 	def get_MetricName(self):
 		return self.get_query_params().get('MetricName')
 
